/** "wbkHost.done" and "wbkHost.sessionModifications" message parameter. */
export interface SessionModifications
{
    /**
     * the header calculation has changed
     * Note: A changed header calculation may also imply that the calculation of all items has changed if
     * some conditions depend on header conditions. In this case the items may not be included in
     * the `updatedItems` array (e.g. for indirect changes).
     */
    headerCalculation: boolean;
    /** the tax scheme has changed */
    taxScheme: boolean;
    /** the currency has changed */
    currency: boolean;
    /** the project data has changed */
    projectData: boolean;
    /** array containing item ids of created items */
    createdItems: Array<string>;
    /** array containing item ids of disposed/deleted items */
    disposedItems: Array<string>;
    /** array containing updated items */
    updatedItems: Array<UpdatedItem>;
}

export interface UpdatedItem
{
    /** id of the updated item */
    itemId: string;
    /**
     * List of changes made to this item stored in a bitmask.
     * Available flags:
     * - 0x00000000 - nothing changed
     * - 0x00000001 - item
     * - 0x00000002 - item properties
     * - 0x00000004 - image
     * - 0x00000008 - calculation
     * - 0x00000010 - tax
     * - 0x00000020 - configuration data
     * - 0x00000040 - user image
     * - 0x00000080 - external item number
     * - 0x00000100 - user item description
     * - 0x00000200 - additional images
     * - 0x00000400 - comments
     * - 0x80000000 - child items also changed
     * - 0xFFFFFFFF - everything changed
     */
    updateFlags: number;
}

/** "wbkHost.reportGenerated" message parameter. */
export interface GeneratedReport
{
    /** name/id of the used report template */
    template: string;
    /** active template options */
    templateOptions?: { [key: string]: ReportTemplateOptionValue };
    /** id of the active basket view */
    basketViewId: string;
    /** Name of the generated pdf. */
    pdfName: string;
    /** Url of the generated report. */
    pdfUrl: string;
}

export type ReportTemplateOptionValue = boolean | string | number | undefined;