const demoLocation = window.location.origin + window.location.pathname;

//You can omit this in your code. Only necessary if changing URL to test server, if BASE_URL is specified in config.js
const baseUrl = typeof BASE_URL !== "undefined" ? BASE_URL : "https://login.pcon-solutions.com";

const loginClient = new PConLogin.PConLoginClient(
  {
    client_id: CLIENT_ID,
    redirect_uri: demoLocation + "redirect.html",
    scope: "create_longterm_token query_account",
    // force_login: true,
  },
  {
    //You can omit this in your code. Only necessary if changing URL to test server.
    base_url: baseUrl 
  }
);

const fetchUserInfo = (accessToken) => {
  const url = new URL('/api/v1/account/user', baseUrl);

  if (accessToken) {
    fetch(url.toString(), {
      headers: {
        Authorization: `Bearer ${accessToken}`,
      },
    })
      .catch((err) => {
        console.error(err);
        const oauthErrorEl = document.querySelector('#oauth_error');
        oauthErrorEl.textContent = err;
        oauthErrorEl.style.display = 'block';
      })
      .then((res) => res.json())
      .then((res) => {
        document.querySelector('#name').textContent = `${res['first_name']} ${res['last_name']}`;
        document.querySelector('#email').textContent = res['email'];
        document.querySelector('#user_info').style.display = 'block';
        document.querySelector('#oauth_error').style.display = 'none';
      });
  } else {
    const oauthErrorEl = document.querySelector('#oauth_error');
    oauthErrorEl.textContent = 'No access token available';
    oauthErrorEl.style.display = 'block';
  }
};

const loginWithRedirect = () => {
  loginClient.loginWithRedirect(demoLocation);
};

const logout = () => {
  loginClient.revokeToken(); //Obsolete if you call .logout() anyway. Here done for demonstration.
  loginClient.logout(demoLocation);

  /**
   * After logging out, you will probably want to logout the user from your application, too,
   * which can be done here.
   */
};

const fetchEndpoint = () => {
  const endpoint = document.querySelector('#endpoint-input').value;
  const orgUrl = new URL(endpoint, baseUrl);

  const fetchPromise = loginClient.fetchWithAuth(orgUrl.toString());

  //Access token available
  if (fetchPromise) {
    fetchPromise
      .then((res) => res.json())
      .then((res) => {
        document.querySelector('#last_request_json').textContent = JSON.stringify(res, null, 2);
      })
      .catch((err) => {
        document.querySelector('#last_request_json').textContent = err;
      });
  }
  //If no access token is available, retrigger login
  else {
    loginWithRedirect();
  }
};

// Login state is determined by getting an access token or getting null.
loginClient.getAccessToken(true).then((accessToken) => {
  const loginState = document.querySelector("#login_state");
  const fetchEndpointButton = document.querySelector("#fetch_endpoint_button");

  if (accessToken) {
    fetchUserInfo(accessToken);

    loginState.textContent = "Logged in";
    loginState.style.color = "#00ff00";
    fetchEndpointButton.disabled = false;
  }
  else {
    loginState.textContent = "Not logged in";
    loginState.style.color = "#ff0000";
    fetchEndpointButton.disabled = true;
  }
});
